@@ -1,7 +1,7 @@
 #' Split the data into training and test datasets
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.split_data}{\code{IAI.split_data}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.split_data}{\code{IAI.split_data}}
 #'
 #' @param task The type of problem.
 #' @param X The features of the data.
@@ -39,7 +39,7 @@ split_data <- function(task, X, ...) {
 #' Fits a model to the training data
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit\%21-Tuple\%7BLearner\%7D}{\code{IAI.fit!}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.fit\%21-Tuple\%7BLearner\%7D}{\code{IAI.fit!}}
 #'
 #' @param obj The learner to fit.
 #' @param X The features of the data.
@@ -56,7 +56,7 @@ fit.learner <- function(obj, X, ...) {
 #' Fits a \code{\link{grid_search}} to the training data
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit\%21-Tuple\%7BGridSearch\%7D}{\code{IAI.fit!}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.fit\%21-Tuple\%7BGridSearch\%7D}{\code{IAI.fit!}}
 #'
 #' @param obj The grid search to fit.
 #' @param X The features of the data.
@@ -76,7 +76,7 @@ fit.grid_search <- function(obj, X, ...) {
 #' please refer to the Julia documentation.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/OptImpute/reference/#IAI.fit\%21-Tuple\%7BLearner\%7BIAIBase.ImputationTask\%7D\%7D}{\code{IAI.fit!}}
+#' \href{https://docs.interpretable.ai/v3.1.1/OptImpute/reference/#IAI.fit\%21-Tuple\%7BLearner\%7BIAIBase.ImputationTask\%7D\%7D}{\code{IAI.fit!}}
 #'
 #' @param obj The learner or grid to fit.
 #' @param X The features of the data.
@@ -94,7 +94,7 @@ fit.imputation_learner <- function(obj, X, ...) {
 #' features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict-Tuple\%7BSupervisedLearner\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.predict-Tuple\%7BSupervisedLearner\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict}}
 #'
 #' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
@@ -110,7 +110,7 @@ predict.supervised_learner <- function(obj, X, ...) {
 #' features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict-Tuple\%7BLearner\%7BIAIBase.SurvivalTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.predict-Tuple\%7BLearner\%7BIAIBase.SurvivalTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict}}
 #'
 #' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
@@ -133,7 +133,7 @@ predict.survival_learner <- function(obj, X, t = NULL, ...) {
 #' Calculate the score for a model on the given data
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.score-Tuple\%7BSupervisedLearner\%7D}{\code{IAI.score}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.score-Tuple\%7BSupervisedLearner\%7D}{\code{IAI.score}}
 #'
 #' @param obj The learner or grid to evaluate.
 #' @param X The features of the data.
@@ -150,7 +150,7 @@ score.supervised_learner <- function(obj, X, ...) {
 #' Calculate the score for a set of predictions on the given data
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.score-Tuple\%7BUnion\%7BAbstractString\%2C\%20Symbol\%7D\%2C\%20Vararg\%7BAny\%7D\%7D}{\code{IAI.score}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.score-Tuple\%7BUnion\%7BAbstractString\%2C\%20Symbol\%7D\%2C\%20Vararg\%7BAny\%7D\%7D}{\code{IAI.score}}
 #'
 #' @param obj The type of problem.
 #' @param predictions The predictions to evaluate.
@@ -175,7 +175,7 @@ score.default <- function(obj, predictions, truths, ...) {
 #' one.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.variable_importance-Tuple\%7BLearner\%7D}{\code{IAI.variable_importance}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.variable_importance-Tuple\%7BLearner\%7D}{\code{IAI.variable_importance}}
 #'
 #' @param obj The learner to query.
 #' @param ... Refer to the Julia documentation for available parameters.
@@ -191,7 +191,7 @@ variable_importance.learner <- function(obj, ...) {
 #' Return the names of the features used by the learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_features_used}{\code{IAI.get_features_used}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.get_features_used}{\code{IAI.get_features_used}}
 #'
 #' @param lnr The learner to query.
 #'
@@ -210,7 +210,7 @@ get_features_used <- function(lnr) {
 #' Output a learner or grid in JSON format
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.write_json}{\code{IAI.write_json}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.write_json}{\code{IAI.write_json}}
 #'
 #' @param filename Where to save the output.
 #' @param obj The learner or grid to output.
@@ -227,7 +227,7 @@ write_json <- function(filename, obj, ...) {
 #' Read in a learner or grid saved in JSON format
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.read_json}{\code{IAI.read_json}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.read_json}{\code{IAI.read_json}}
 #'
 #' @param filename The location of the JSON file.
 #'
@@ -242,7 +242,7 @@ read_json <- function(filename) {
 #' Resume training from a checkpoint file
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.resume_from_checkpoint}{\code{IAI.resume_from_checkpoint}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.resume_from_checkpoint}{\code{IAI.resume_from_checkpoint}}
 #'
 #' @param checkpoint_file The location of the checkpoint file.
 #'
@@ -267,7 +267,7 @@ resume_from_checkpoint <- function(checkpoint_file) {
 #' Return the value of all parameters on a learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_params}{\code{IAI.get_params}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.get_params}{\code{IAI.get_params}}
 #'
 #' @param lnr The learner to query.
 #'
@@ -282,7 +282,7 @@ get_params <- function(lnr) {
 #' Set all supplied parameters on a learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.set_params!}{\code{IAI.set_params!}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.set_params!}{\code{IAI.set_params!}}
 #'
 #' @param lnr The learner to modify.
 #' @param ... The parameters to set on the learner.
@@ -299,7 +299,7 @@ set_params <- function(lnr, ...) {
 #' Return an unfitted copy of a learner with the same parameters
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.clone}{\code{IAI.clone}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.clone}{\code{IAI.clone}}
 #'
 #' @param lnr The learner to copy.
 #'
@@ -314,7 +314,7 @@ clone <- function(lnr) {
 #' Show interactive visualization of an object in the default browser
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.show_in_browser-Tuple\%7BAbstractVisualization\%7D}{\code{IAI.show_in_browser}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.show_in_browser-Tuple\%7BAbstractVisualization\%7D}{\code{IAI.show_in_browser}}
 #'
 #' @param obj The object to visualize.
 #' @param ... Refer to the Julia documentation for available parameters.
@@ -329,7 +329,7 @@ show_in_browser.abstract_visualization <- function(obj, ...) {
 #' browser
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.show_in_browser-Tuple\%7BROCCurve\%7D}{\code{IAI.show_in_browser}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.show_in_browser-Tuple\%7BROCCurve\%7D}{\code{IAI.show_in_browser}}
 #'
 #' @param obj The curve to visualize.
 #' @param ... Refer to the Julia documentation for available parameters.
@@ -349,7 +349,7 @@ show_in_browser.roc_curve <- function(obj, ...) {
 #' Sets a global rich output parameter
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.set_rich_output_param!}{\code{IAI.set_rich_output_param!}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.set_rich_output_param!}{\code{IAI.set_rich_output_param!}}
 #'
 #' @param key The parameter to set.
 #' @param value The value to set
@@ -365,7 +365,7 @@ set_rich_output_param <- function(key, value) {
 #' Return the current global rich output parameter settings
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_rich_output_params}{\code{IAI.get_rich_output_params}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.get_rich_output_params}{\code{IAI.get_rich_output_params}}
 #'
 #' @examples \dontrun{iai::get_rich_output_params()}
 #'
@@ -378,7 +378,7 @@ get_rich_output_params <- function() {
 #' Delete a global rich output parameter
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.delete_rich_output_param!}{\code{IAI.delete_rich_output_param!}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.delete_rich_output_param!}{\code{IAI.delete_rich_output_param!}}
 #'
 #' @param key The parameter to delete.
 #'
@@ -393,7 +393,7 @@ delete_rich_output_param <- function(key) {
 #' Controls grid search over parameter combinations
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.GridSearch}{\code{IAI.GridSearch}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.GridSearch}{\code{IAI.GridSearch}}
 #'
 #' @param lnr The learner to use when validating.
 #' @param ... The parameters to validate over.
@@ -409,7 +409,7 @@ grid_search <- function(lnr, ...) {
 #' Fits a grid search to the training data with cross-validation
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit_cv\%21-Tuple\%7BGridSearch\%7D}{\code{IAI.fit_cv!}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.fit_cv\%21-Tuple\%7BGridSearch\%7D}{\code{IAI.fit_cv!}}
 #'
 #' @param grid The grid to fit.
 #' @param X The features of the data.
@@ -429,7 +429,7 @@ fit_cv <- function(grid, X, ...) {
 #' Return the fitted learner using the best parameter combination from a grid
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_learner}{\code{IAI.get_learner}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.get_learner}{\code{IAI.get_learner}}
 #'
 #' @param grid The grid to query.
 #'
@@ -444,7 +444,7 @@ get_learner <- function(grid) {
 #' Return the best parameter combination from a grid
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_best_params}{\code{IAI.get_best_params}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.get_best_params}{\code{IAI.get_best_params}}
 #'
 #' @param grid The grid search to query.
 #'
@@ -476,7 +476,7 @@ get_grid_results <- function(grid) {
 #' Return a summary of the results from the grid search
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_grid_result_summary}{\code{IAI.get_grid_result_summary}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.get_grid_result_summary}{\code{IAI.get_grid_result_summary}}
 #'
 #' @param grid The grid search to query.
 #'
@@ -495,7 +495,7 @@ get_grid_result_summary <- function(grid) {
 #' Return a vector of lists detailing the results of the grid search
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_grid_result_details}{\code{IAI.get_grid_result_details}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.get_grid_result_details}{\code{IAI.get_grid_result_details}}
 #'
 #' @param grid The grid search to query.
 #'
@@ -525,7 +525,7 @@ get_grid_result_details <- function(grid) {
 #' learner for each point in the features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_proba-Tuple\%7BLearner\%7BIAIBase.ClassificationTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_proba}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.predict_proba-Tuple\%7BLearner\%7BIAIBase.ClassificationTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_proba}}
 #'
 #' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
@@ -543,7 +543,7 @@ predict_proba.classification_learner <- function(obj, X, ...) {
 #' data
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.ROCCurve-Tuple\%7BLearner\%7BIAIBase.ClassificationTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%2C\%20AbstractVector\%7D}{\code{IAI.ROCCurve}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.ROCCurve-Tuple\%7BLearner\%7BIAIBase.ClassificationTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%2C\%20AbstractVector\%7D}{\code{IAI.ROCCurve}}
 #'
 #' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
@@ -559,7 +559,7 @@ roc_curve.classification_learner <- function(obj, X, y, ...) {
 #' Construct an ROC curve from predicted probabilities and true labels
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.ROCCurve-Tuple\%7BAbstractVector\%7B\%3C\%3AReal\%7D\%2C\%20AbstractVector\%7D}{\code{IAI.ROCCurve}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.ROCCurve-Tuple\%7BAbstractVector\%7B\%3C\%3AReal\%7D\%2C\%20AbstractVector\%7D}{\code{IAI.ROCCurve}}
 #'
 #' @param obj The predicted probabilities for each point in the data.
 #' @param y The true labels of the data.
@@ -586,7 +586,7 @@ roc_curve.default <- function(
 
 #' Construct a \href{https://ggplot2.tidyverse.org/reference/ggplot.html}{\code{ggplot2::ggplot}} object plotting the ROC curve
 #'
-#' @param x The ROC curve to plot
+#' @param object The ROC curve to plot
 #' @param ... Additional arguments (unused)
 #'
 #' @examples \dontrun{ggplot2::autoplot(roc)}
@@ -597,10 +597,10 @@ roc_curve.default <- function(
 #' @importFrom ggplot2 autoplot
 #' @importFrom rlang .data
 #' @export
-autoplot.roc_curve <- function(x, ...) {
+autoplot.roc_curve <- function(object, ...) {
   requires_iai_version("2.1.0", "ggplot2::autoplot.roc_curve")
 
-  d <- get_roc_curve_data(x)
+  d <- get_roc_curve_data(object)
 
   tpr <- sapply(d$coords, `[[`, "tpr")
   fpr <- sapply(d$coords, `[[`, "fpr")
@@ -646,7 +646,7 @@ plot.roc_curve <- function(x, ...) {
 #' (the threshold).
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_roc_curve_data}{\code{IAI.get_roc_curve_data}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.get_roc_curve_data}{\code{IAI.get_roc_curve_data}}
 #'
 #' @param curve The curve to query.
 #'
@@ -672,7 +672,7 @@ get_roc_curve_data <- function(curve) {
 #' probability for each breakpoint on the curve.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.get_survival_curve_data}{\code{IAI.get_survival_curve_data}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.get_survival_curve_data}{\code{IAI.get_survival_curve_data}}
 #'
 #' @param curve The curve to query.
 #'
@@ -691,7 +691,7 @@ get_survival_curve_data <- function(curve) {
 #' survival time.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_hazard-Tuple\%7BLearner\%7BIAIBase.SurvivalTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_hazard}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.predict_hazard-Tuple\%7BLearner\%7BIAIBase.SurvivalTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_hazard}}
 #'
 #' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
@@ -713,7 +713,7 @@ predict_hazard.survival_learner <- function(obj, X, ...) {
 #' each point in the features.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_expected_survival_time-Tuple\%7BLearner\%7BIAIBase.SurvivalTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_expected_survival_time}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.predict_expected_survival_time-Tuple\%7BLearner\%7BIAIBase.SurvivalTask\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_expected_survival_time}}
 #'
 #' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
@@ -737,7 +737,7 @@ predict_expected_survival_time.survival_learner <- function(obj, X, ...) {
 #' \code{\link{get_survival_curve}})
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_expected_survival_time-Tuple\%7BSurvivalCurve\%7D}{\code{IAI.predict_expected_survival_time}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.predict_expected_survival_time-Tuple\%7BSurvivalCurve\%7D}{\code{IAI.predict_expected_survival_time}}
 #'
 #' @param obj The survival curve to use for prediction.
 #' @param ... Additional arguments (unused)
@@ -759,7 +759,7 @@ predict_expected_survival_time.survival_curve <- function(obj, ...) {
 #' learner for each point in the features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_outcomes-Tuple\%7BPrescriptionLearner\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_outcomes}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.predict_outcomes-Tuple\%7BPrescriptionLearner\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_outcomes}}
 #'
 #' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
@@ -775,7 +775,7 @@ predict_outcomes.prescription_learner <- function(obj, X, ...) {
 #' learner for each point in the features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_outcomes-Tuple\%7BPolicyLearner\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_outcomes}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.predict_outcomes-Tuple\%7BPolicyLearner\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%2C\%20Union\%7BDataFrames.AbstractDataFrame\%2C\%20AbstractMatrix\%7B\%3C\%3AReal\%7D\%7D\%7D}{\code{IAI.predict_outcomes}}
 #'
 #' @param obj The learner or grid to use for prediction.
 #' @param X The features of the data.
@@ -798,7 +798,7 @@ predict_outcomes.policy_learner <- function(obj, X, rewards, ...) {
 #' features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_treatment_rank}{\code{IAI.predict_treatment_rank}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.predict_treatment_rank}{\code{IAI.predict_treatment_rank}}
 #'
 #' @param lnr The learner or grid to use for prediction.
 #' @param X The features of the data.
@@ -819,7 +819,7 @@ predict_treatment_rank <- function(lnr, X) {
 #' learner for each point in the features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.predict_treatment_outcome}{\code{IAI.predict_treatment_outcome}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.predict_treatment_outcome}{\code{IAI.predict_treatment_outcome}}
 #'
 #' @param lnr The learner or grid to use for prediction.
 #' @param X The features of the data.
@@ -836,10 +836,31 @@ predict_treatment_outcome <- function(lnr, X) {
 }
 
 
+#' Return the standard error for the estimated quality of each treatment in the
+#' trained model of the learner for each point in the features
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.predict_treatment_outcome_standard_error}{\code{IAI.predict_treatment_outcome_standard_error}}
+#'
+#' @param lnr The learner or grid to use for prediction.
+#' @param X The features of the data.
+#'
+#' @examples \dontrun{iai::predict_treatment_outcome_standard_error(lnr, X)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 3.2 or higher.
+#'
+#' @export
+predict_treatment_outcome_standard_error <- function(lnr, X) {
+  requires_iai_version("3.2.0", "predict_treatment_outcome_standard_error")
+  jl_func("IAI.predict_treatment_outcome_standard_error_convert", lnr, X)
+}
+
+
 #' Impute missing values in a dataframe using a fitted imputation model
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.transform}{\code{IAI.transform}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.transform}{\code{IAI.transform}}
 #'
 #' @param lnr The learner or grid to use for imputation
 #' @param X The features of the data.
@@ -861,7 +882,7 @@ transform <- function(lnr, X) {
 #' \code{\link{transform}}
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit_transform!}{\code{IAI.fit_transform!}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.fit_transform!}{\code{IAI.fit_transform!}}
 #'
 #' @param lnr The learner or grid to use for imputation
 #' @param X The features of the data.
@@ -879,7 +900,7 @@ fit_transform <- function(lnr, X, ...) {
 #' values in these features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.fit_transform_cv!}{\code{IAI.fit_transform_cv!}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.fit_transform_cv!}{\code{IAI.fit_transform_cv!}}
 #'
 #' @param grid The grid to use for imputation
 #' @param X The features of the data.
@@ -896,7 +917,7 @@ fit_transform_cv <- function(grid, X, ...) {
 #' Output an object as an interactive browser visualization in HTML format
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.write_html-Tuple\%7BAny\%2C\%20AbstractVisualization\%7D}{\code{IAI.write_html}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.write_html-Tuple\%7BAny\%2C\%20AbstractVisualization\%7D}{\code{IAI.write_html}}
 #'
 #' @param filename Where to save the output.
 #' @param obj The object to output.
@@ -911,7 +932,7 @@ write_html.abstract_visualization <- function(filename, obj, ...) {
 #' Output an ROC curve as an interactive browser visualization in HTML format
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.write_html-Tuple\%7BAny\%2C\%20ROCCurve\%7D}{\code{IAI.write_html}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.write_html-Tuple\%7BAny\%2C\%20ROCCurve\%7D}{\code{IAI.write_html}}
 #'
 #' @param filename Where to save the output.
 #' @param obj The curve to output.
@@ -932,13 +953,13 @@ write_html.roc_curve <- function(filename, obj, ...) {
 #' Construct an interactive questionnaire from multiple specified learners
 #'
 #' Refer to the
-#' \href{https://docs.interpretable.ai/v3.1.0/IAI-R/julia/#R-Interactive-Visualizations-1}{documentation on advanced tree visualization}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAI-R/julia/#R-Interactive-Visualizations-1}{documentation on advanced tree visualization}
 #' for more information.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.MultiQuestionnaire-Tuple\%7BPair\%7D}{\code{IAI.MultiQuestionnaire}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.MultiQuestionnaire-Tuple\%7BPair\%7D}{\code{IAI.MultiQuestionnaire}}
 #'
-#' @param obj The questions to visualize. Refer to the \href{https://docs.interpretable.ai/v3.1.0/IAITrees/visualization/#multivis-1}{Julia documentation on multi-learner visualizations} for more information.
+#' @param obj The questions to visualize. Refer to the \href{https://docs.interpretable.ai/v3.1.1/IAITrees/visualization/#multivis-1}{Julia documentation on multi-learner visualizations} for more information.
 #' @param ... Additional arguments (unused)
 #'
 #' @examples
@@ -963,7 +984,7 @@ multi_questionnaire.default <- function(obj, ...) {
 #' results of a grid search
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAIBase/reference/#IAI.MultiQuestionnaire-Tuple\%7BGridSearch\%7D}{\code{IAI.MultiQuestionnaire}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAIBase/reference/#IAI.MultiQuestionnaire-Tuple\%7BGridSearch\%7D}{\code{IAI.MultiQuestionnaire}}
 #'
 #' @param obj The grid to visualize
 #' @param ... Additional arguments (unused)
