@@ -1,7 +1,7 @@
 #' Return the number of nodes in a trained learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_num_nodes}{\code{IAI.get_num_nodes}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_num_nodes}{\code{IAI.get_num_nodes}}
 #'
 #' @param lnr The learner to query.
 #'
@@ -16,7 +16,7 @@ get_num_nodes <- function(lnr) {
 #' Check if a node of a tree is a leaf
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_leaf}{\code{IAI.is_leaf}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.is_leaf}{\code{IAI.is_leaf}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -32,7 +32,7 @@ is_leaf <- function(lnr, node_index) {
 #' Get the depth of a node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_depth}{\code{IAI.get_depth}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_depth}{\code{IAI.get_depth}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -48,7 +48,7 @@ get_depth <- function(lnr, node_index) {
 #' Get the number of training points contained in a node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_num_samples}{\code{IAI.get_num_samples}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_num_samples}{\code{IAI.get_num_samples}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -64,7 +64,7 @@ get_num_samples <- function(lnr, node_index) {
 #' Get the index of the parent node at a node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_parent}{\code{IAI.get_parent}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_parent}{\code{IAI.get_parent}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -80,7 +80,7 @@ get_parent <- function(lnr, node_index) {
 #' Get the index of the lower child at a split node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_lower_child}{\code{IAI.get_lower_child}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_lower_child}{\code{IAI.get_lower_child}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -96,7 +96,7 @@ get_lower_child <- function(lnr, node_index) {
 #' Get the index of the upper child at a split node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_upper_child}{\code{IAI.get_upper_child}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_upper_child}{\code{IAI.get_upper_child}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -112,7 +112,7 @@ get_upper_child <- function(lnr, node_index) {
 #' Check if a node of a tree applies a parallel split
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_parallel_split}{\code{IAI.is_parallel_split}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.is_parallel_split}{\code{IAI.is_parallel_split}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -128,7 +128,7 @@ is_parallel_split <- function(lnr, node_index) {
 #' Check if a node of a tree applies a hyperplane split
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_hyperplane_split}{\code{IAI.is_hyperplane_split}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.is_hyperplane_split}{\code{IAI.is_hyperplane_split}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -144,7 +144,7 @@ is_hyperplane_split <- function(lnr, node_index) {
 #' Check if a node of a tree applies a categoric split
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_categoric_split}{\code{IAI.is_categoric_split}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.is_categoric_split}{\code{IAI.is_categoric_split}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -160,7 +160,7 @@ is_categoric_split <- function(lnr, node_index) {
 #' Check if a node of a tree applies a ordinal split
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_ordinal_split}{\code{IAI.is_ordinal_split}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.is_ordinal_split}{\code{IAI.is_ordinal_split}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -176,7 +176,7 @@ is_ordinal_split <- function(lnr, node_index) {
 #' Check if a node of a tree applies a mixed parallel/categoric split
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_mixed_parallel_split}{\code{IAI.is_mixed_parallel_split}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.is_mixed_parallel_split}{\code{IAI.is_mixed_parallel_split}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -192,7 +192,7 @@ is_mixed_parallel_split <- function(lnr, node_index) {
 #' Check if a node of a tree applies a mixed ordinal/categoric split
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.is_mixed_ordinal_split}{\code{IAI.is_mixed_ordinal_split}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.is_mixed_ordinal_split}{\code{IAI.is_mixed_ordinal_split}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -209,7 +209,7 @@ is_mixed_ordinal_split <- function(lnr, node_index) {
 #' of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.missing_goes_lower}{\code{IAI.missing_goes_lower}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.missing_goes_lower}{\code{IAI.missing_goes_lower}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -225,7 +225,7 @@ missing_goes_lower <- function(lnr, node_index) {
 #' Return the feature used in the split at a node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_split_feature}{\code{IAI.get_split_feature}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_split_feature}{\code{IAI.get_split_feature}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -241,7 +241,7 @@ get_split_feature <- function(lnr, node_index) {
 #' Return the threshold used in the split at a node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_split_threshold}{\code{IAI.get_split_threshold}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_split_threshold}{\code{IAI.get_split_threshold}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -258,7 +258,7 @@ get_split_threshold <- function(lnr, node_index) {
 #' tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_split_categories}{\code{IAI.get_split_categories}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_split_categories}{\code{IAI.get_split_categories}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -275,7 +275,7 @@ get_split_categories <- function(lnr, node_index) {
 #' split at a node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_split_weights}{\code{IAI.get_split_weights}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_split_weights}{\code{IAI.get_split_weights}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -293,7 +293,7 @@ get_split_weights <- function(lnr, node_index) {
 #' Return the predicted label at a node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_classification_label}{\code{IAI.get_classification_label}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_classification_label}{\code{IAI.get_classification_label}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -310,7 +310,7 @@ get_classification_label <- function(lnr, node_index, ...) {
 #' Return the predicted probabilities of class membership at a node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_classification_proba}{\code{IAI.get_classification_proba}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_classification_proba}{\code{IAI.get_classification_proba}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -328,7 +328,7 @@ get_classification_proba <- function(lnr, node_index, ...) {
 #' classification tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_constant-Tuple\%7BClassificationTreeLearner\%2C\%20Int64\%7D}{\code{IAI.get_regression_constant}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_regression_constant-Tuple\%7BClassificationTreeLearner\%2C\%20Int64\%7D}{\code{IAI.get_regression_constant}}
 #'
 #' @param obj The learner to query.
 #' @param node_index The node in the tree to query.
@@ -351,7 +351,7 @@ get_regression_constant.classification_tree_learner <- function(obj, node_index,
 #' regression tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_constant-Tuple\%7BRegressionTreeLearner\%2C\%20Int64\%7D}{\code{IAI.get_regression_constant}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_regression_constant-Tuple\%7BRegressionTreeLearner\%2C\%20Int64\%7D}{\code{IAI.get_regression_constant}}
 #'
 #' @param obj The learner to query.
 #' @param node_index The node in the tree to query.
@@ -369,7 +369,7 @@ get_regression_constant.regression_tree_learner <- function(obj, node_index,
 #' survival tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_constant-Tuple\%7BSurvivalTreeLearner\%2C\%20Int64\%7D}{\code{IAI.get_regression_constant}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_regression_constant-Tuple\%7BSurvivalTreeLearner\%2C\%20Int64\%7D}{\code{IAI.get_regression_constant}}
 #'
 #' @param obj The learner to query.
 #' @param node_index The node in the tree to query.
@@ -392,7 +392,7 @@ get_regression_constant.survival_tree_learner <- function(obj, node_index,
 #' prescription tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_constant-Tuple\%7BPrescriptionTreeLearner\%2C\%20Int64\%2C\%20Any\%7D}{\code{IAI.get_regression_constant}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_regression_constant-Tuple\%7BPrescriptionTreeLearner\%2C\%20Int64\%2C\%20Any\%7D}{\code{IAI.get_regression_constant}}
 #'
 #' @param obj The learner to query.
 #' @param node_index The node in the tree to query.
@@ -413,7 +413,7 @@ get_regression_constant.prescription_tree_learner <- function(obj, node_index,
 #' a node of a classification tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_weights-Tuple\%7BClassificationTreeLearner\%2C\%20Int64\%7D}{\code{IAI.get_regression_weights}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_regression_weights-Tuple\%7BClassificationTreeLearner\%2C\%20Int64\%7D}{\code{IAI.get_regression_weights}}
 #'
 #' @param obj The learner to query.
 #' @param node_index The node in the tree to query.
@@ -436,7 +436,7 @@ get_regression_weights.classification_tree_learner <- function(obj, node_index,
 #' node of a regression tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_weights-Tuple\%7BRegressionTreeLearner\%2C\%20Int64\%7D}{\code{IAI.get_regression_weights}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_regression_weights-Tuple\%7BRegressionTreeLearner\%2C\%20Int64\%7D}{\code{IAI.get_regression_weights}}
 #'
 #' @param obj The learner to query.
 #' @param node_index The node in the tree to query.
@@ -454,7 +454,7 @@ get_regression_weights.regression_tree_learner <- function(obj, node_index,
 #' node of a survival tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_weights-Tuple\%7BSurvivalTreeLearner\%2C\%20Int64\%7D}{\code{IAI.get_regression_weights}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_regression_weights-Tuple\%7BSurvivalTreeLearner\%2C\%20Int64\%7D}{\code{IAI.get_regression_weights}}
 #'
 #' @param obj The learner to query.
 #' @param node_index The node in the tree to query.
@@ -476,7 +476,7 @@ get_regression_weights.survival_tree_learner <- function(obj, node_index, ...) {
 #' node of a prescription tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_regression_weights-Tuple\%7BPrescriptionTreeLearner\%2C\%20Int64\%2C\%20Any\%7D}{\code{IAI.get_regression_weights}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_regression_weights-Tuple\%7BPrescriptionTreeLearner\%2C\%20Int64\%2C\%20Any\%7D}{\code{IAI.get_regression_weights}}
 #'
 #' @param obj The learner to query.
 #' @param node_index The node in the tree to query.
@@ -496,7 +496,7 @@ get_regression_weights.prescription_tree_learner <- function(obj, node_index,
 #' Return the survival curve at a node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_survival_curve}{\code{IAI.get_survival_curve}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_survival_curve}{\code{IAI.get_survival_curve}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -513,7 +513,7 @@ get_survival_curve <- function(lnr, node_index, ...) {
 #' Return the predicted expected survival time at a node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_survival_expected_time}{\code{IAI.get_survival_expected_time}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_survival_expected_time}{\code{IAI.get_survival_expected_time}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -534,7 +534,7 @@ get_survival_expected_time <- function(lnr, node_index, ...) {
 #' Return the predicted hazard ratio at a node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_survival_hazard}{\code{IAI.get_survival_hazard}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_survival_hazard}{\code{IAI.get_survival_hazard}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -556,7 +556,7 @@ get_survival_hazard <- function(lnr, node_index, ...) {
 #' node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_prescription_treatment_rank}{\code{IAI.get_prescription_treatment_rank}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_prescription_treatment_rank}{\code{IAI.get_prescription_treatment_rank}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -574,7 +574,7 @@ get_prescription_treatment_rank <- function(lnr, node_index, ...) {
 #' node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_policy_treatment_rank}{\code{IAI.get_policy_treatment_rank}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_policy_treatment_rank}{\code{IAI.get_policy_treatment_rank}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -595,7 +595,7 @@ get_policy_treatment_rank <- function(lnr, node_index, ...) {
 #' Return the quality of the treatments at a node of a tree
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_policy_treatment_outcome}{\code{IAI.get_policy_treatment_outcome}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_policy_treatment_outcome}{\code{IAI.get_policy_treatment_outcome}}
 #'
 #' @param lnr The learner to query.
 #' @param node_index The node in the tree to query.
@@ -613,11 +613,34 @@ get_policy_treatment_outcome <- function(lnr, node_index, ...) {
 }
 
 
+#' Return the standard error for the quality of the treatments at a node of a
+#' tree
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_policy_treatment_outcome_standard_error}{\code{IAI.get_policy_treatment_outcome_standard_error}}
+#'
+#' @param lnr The learner to query.
+#' @param node_index The node in the tree to query.
+#' @param ... Refer to the Julia documentation for available parameters.
+#'
+#' @examples \dontrun{iai::get_policy_treatment_outcome_standard_error(lnr, 1)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 3.2 or higher.
+#'
+#' @export
+get_policy_treatment_outcome_standard_error <- function(lnr, node_index, ...) {
+  requires_iai_version("3.2.0", "get_policy_treatment_outcome_standard_error")
+  jl_func("IAI.get_policy_treatment_outcome_standard_error_convert", lnr,
+          node_index, ...)
+}
+
+
 #' Return the leaf index in a tree model into which each point in the features
 #' falls
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.apply}{\code{IAI.apply}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.apply}{\code{IAI.apply}}
 #'
 #' @param lnr The learner or grid to query.
 #' @param X The features of the data.
@@ -633,7 +656,7 @@ apply <- function(lnr, X) {
 #' a trained tree model
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.apply_nodes}{\code{IAI.apply_nodes}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.apply_nodes}{\code{IAI.apply_nodes}}
 #'
 #' @param lnr The learner or grid to query.
 #' @param X The features of the data.
@@ -650,7 +673,7 @@ apply_nodes <- function(lnr, X) {
 #' the features passes through the \code{j}th node in a trained tree model.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.decision_path}{\code{IAI.decision_path}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.decision_path}{\code{IAI.decision_path}}
 #'
 #' @param lnr The learner or grid to query.
 #' @param X The features of the data.
@@ -666,7 +689,7 @@ decision_path <- function(lnr, X) {
 #' Print the decision path through the learner for each sample in the features
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.print_path}{\code{IAI.print_path}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.print_path}{\code{IAI.print_path}}
 #'
 #' @param lnr The learner or grid to query.
 #' @param X The features of the data.
@@ -689,7 +712,7 @@ print_path <- function(lnr, X, ...) {
 #' one.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.variable_importance-Tuple\%7BTreeLearner\%7D}{\code{IAI.variable_importance}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.variable_importance-Tuple\%7BTreeLearner\%7D}{\code{IAI.variable_importance}}
 #'
 #' @param obj The learner to query.
 #' @param ... Refer to the Julia documentation for available parameters.
@@ -707,7 +730,7 @@ variable_importance.tree_learner <- function(obj, ...) {
 #' at least the specified threshold.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.set_threshold!}{\code{IAI.set_threshold!}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.set_threshold!}{\code{IAI.set_threshold!}}
 #'
 #' @param lnr The learner to modify.
 #' @param label The referenced label.
@@ -727,11 +750,11 @@ set_threshold <- function(lnr, label, threshold, ...) {
 #' Output a learner as a PNG image
 #'
 #' Before using this function, either run \code{\link{load_graphviz}} or ensure
-#' that \href{http://graphviz.org}{Graphviz} is installed and on the system
+#' that \href{https://graphviz.org/}{Graphviz} is installed and on the system
 #' \code{PATH}
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.write_png}{\code{IAI.write_png}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.write_png}{\code{IAI.write_png}}
 #'
 #' @param filename Where to save the output.
 #' @param lnr The learner to output.
@@ -748,11 +771,11 @@ write_png <- function(filename, lnr, ...) {
 #' Output a learner as a PDF image
 #'
 #' Before using this function, either run \code{\link{load_graphviz}} or ensure
-#' that \href{http://graphviz.org}{Graphviz} is installed and on the system
+#' that \href{https://graphviz.org/}{Graphviz} is installed and on the system
 #' \code{PATH}
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.write_pdf}{\code{IAI.write_pdf}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.write_pdf}{\code{IAI.write_pdf}}
 #'
 #' @param filename Where to save the output.
 #' @param lnr The learner to output.
@@ -773,11 +796,11 @@ write_pdf <- function(filename, lnr, ...) { # nocov start
 #' Output a learner as a SVG image
 #'
 #' Before using this function, either run \code{\link{load_graphviz}} or ensure
-#' that \href{http://graphviz.org}{Graphviz} is installed and on the system
+#' that \href{https://graphviz.org/}{Graphviz} is installed and on the system
 #' \code{PATH}
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.write_svg}{\code{IAI.write_svg}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.write_svg}{\code{IAI.write_svg}}
 #'
 #' @param filename Where to save the output.
 #' @param lnr The learner to output.
@@ -796,10 +819,10 @@ write_svg <- function(filename, lnr, ...) { # nocov start
 
 
 #' Output a learner in
-#' \href{http://www.graphviz.org/content/dot-language/}{.dot format}
+#' \href{https://www.graphviz.org/content/dot-language/}{.dot format}
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.write_dot}{\code{IAI.write_dot}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.write_dot}{\code{IAI.write_dot}}
 #'
 #' @param filename Where to save the output.
 #' @param lnr The learner to output.
@@ -816,7 +839,7 @@ write_dot <- function(filename, lnr, ...) {
 #' Output a tree learner as an interactive browser visualization in HTML format
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.write_html-Tuple\%7BAny\%2C\%20TreeLearner\%7D}{\code{IAI.write_html}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.write_html-Tuple\%7BAny\%2C\%20TreeLearner\%7D}{\code{IAI.write_html}}
 #'
 #' @param filename Where to save the output.
 #' @param obj The learner or grid to output.
@@ -839,7 +862,7 @@ write_html.tree_learner <- function(filename, obj, ...) {
 #' Show interactive tree visualization of a tree learner in the default browser
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.show_in_browser-Tuple\%7BTreeLearner\%7D}{\code{IAI.show_in_browser}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.show_in_browser-Tuple\%7BTreeLearner\%7D}{\code{IAI.show_in_browser}}
 #'
 #' @param obj The learner or grid to visualize.
 #' @param ... Refer to the Julia documentation for available parameters.
@@ -861,7 +884,7 @@ show_in_browser.tree_learner <- function(obj, ...) {
 #' Output a tree learner as an interactive questionnaire in HTML format
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.write_questionnaire-Tuple\%7BAny\%2C\%20TreeLearner\%7D}{\code{IAI.write_questionnaire}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.write_questionnaire-Tuple\%7BAny\%2C\%20TreeLearner\%7D}{\code{IAI.write_questionnaire}}
 #'
 #' @param filename Where to save the output.
 #' @param obj The learner or grid to output.
@@ -884,7 +907,7 @@ write_questionnaire.tree_learner <- function(filename, obj, ...) {
 #' Show an interactive questionnaire based on a tree learner in default browser
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.show_questionnaire-Tuple\%7BTreeLearner\%7D}{\code{IAI.show_questionnaire}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.show_questionnaire-Tuple\%7BTreeLearner\%7D}{\code{IAI.show_questionnaire}}
 #'
 #' @param obj The learner or grid to visualize.
 #' @param ... Refer to the Julia documentation for available parameters.
@@ -906,7 +929,7 @@ show_questionnaire.tree_learner <- function(obj, ...) {
 #' Show the probability of a specified label when visualizing a learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.set_display_label!}{\code{IAI.set_display_label!}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.set_display_label!}{\code{IAI.set_display_label!}}
 #'
 #' @param lnr The learner to modify.
 #' @param display_label The label for which to show probabilities.
@@ -924,7 +947,7 @@ set_display_label <- function(lnr, display_label) {
 #' when visualizing a learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.reset_display_label!}{\code{IAI.reset_display_label!}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.reset_display_label!}{\code{IAI.reset_display_label!}}
 #'
 #' @param lnr The learner to modify.
 #'
@@ -940,10 +963,10 @@ reset_display_label <- function(lnr) {
 #' Specify an interactive tree visualization of a tree learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.TreePlot-Tuple\%7BTreeLearner\%7D}{\code{IAI.TreePlot}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.TreePlot-Tuple\%7BTreeLearner\%7D}{\code{IAI.TreePlot}}
 #'
 #' @param lnr The learner to visualize.
-#' @param ... Refer to the \href{https://docs.interpretable.ai/v3.1.0/IAITrees/advanced/#Advanced-Visualization-1}{Julia documentation on advanced tree visualization} for available parameters.
+#' @param ... Refer to the \href{https://docs.interpretable.ai/v3.1.1/IAITrees/advanced/#Advanced-Visualization-1}{Julia documentation on advanced tree visualization} for available parameters.
 #'
 #' @examples \dontrun{iai::tree_plot(lnr)}
 #'
@@ -960,10 +983,10 @@ tree_plot <- function(lnr, ...) {
 #' Specify an interactive questionnaire of a tree learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.Questionnaire-Tuple\%7BTreeLearner\%7D}{\code{IAI.Questionnaire}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.Questionnaire-Tuple\%7BTreeLearner\%7D}{\code{IAI.Questionnaire}}
 #'
 #' @param obj The learner to visualize.
-#' @param ... Refer to the \href{https://docs.interpretable.ai/v3.1.0/IAITrees/advanced/#Advanced-Visualization-1}{Julia documentation} for available parameters.
+#' @param ... Refer to the \href{https://docs.interpretable.ai/v3.1.1/IAITrees/advanced/#Advanced-Visualization-1}{Julia documentation} for available parameters.
 #'
 #' @examples \dontrun{iai::questionnaire(lnr)}
 #'
@@ -981,13 +1004,13 @@ questionnaire.tree_learner <- function(obj, ...) {
 #' specified by questions
 #'
 #' Refer to the
-#' \href{https://docs.interpretable.ai/v3.1.0/IAI-R/julia/#R-Interactive-Visualizations-1}{documentation on advanced tree visualization}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAI-R/julia/#R-Interactive-Visualizations-1}{documentation on advanced tree visualization}
 #' for more information.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.MultiTreePlot-Tuple\%7BPair\%7D}{\code{IAI.MultiTreePlot}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.MultiTreePlot-Tuple\%7BPair\%7D}{\code{IAI.MultiTreePlot}}
 #'
-#' @param obj The questions to visualize. Refer to the \href{https://docs.interpretable.ai/v3.1.0/IAITrees/visualization/#multivis-1}{Julia documentation on multi-learner visualizations} for more information.
+#' @param obj The questions to visualize. Refer to the \href{https://docs.interpretable.ai/v3.1.1/IAITrees/visualization/#multivis-1}{Julia documentation on multi-learner visualizations} for more information.
 #' @param ... Additional arguments (unused)
 #'
 #' @examples
@@ -1012,7 +1035,7 @@ multi_tree_plot.default <- function(obj, ...) {
 #' the results of a grid search
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.MultiTreePlot-Tuple\%7BGridSearch\%7D}{\code{IAI.MultiTreePlot}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.MultiTreePlot-Tuple\%7BGridSearch\%7D}{\code{IAI.MultiTreePlot}}
 #'
 #' @param obj The grid to visualize
 #' @param ... Additional arguments (unused)
@@ -1033,7 +1056,7 @@ multi_tree_plot.grid_search <- function(obj, ...) {
 #' in new tree learner using variable importance scores.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.variable_importance_similarity}{\code{IAI.variable_importance_similarity}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.variable_importance_similarity}{\code{IAI.variable_importance_similarity}}
 #'
 #' @param lnr The original learner
 #' @param new_lnr The new learner
@@ -1055,7 +1078,7 @@ variable_importance_similarity <- function(lnr, new_lnr, ...) {
 #' with the best training objective.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_tree}{\code{IAI.get_tree}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_tree}{\code{IAI.get_tree}}
 #'
 #' @param lnr The original learner
 #' @param index The index of the tree to use
@@ -1077,11 +1100,11 @@ get_tree <- function(lnr, index) {
 #' performance and similarity to the original tree
 #'
 #' Refer to the
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/stability/#Tree-Stability-1}{documentation on tree stability}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/stability/#Tree-Stability-1}{documentation on tree stability}
 #' for more information.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.SimilarityComparison}{\code{IAI.SimilarityComparison}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.SimilarityComparison}{\code{IAI.SimilarityComparison}}
 #'
 #' @param lnr The original learner
 #' @param new_lnr The new learner
@@ -1105,7 +1128,7 @@ similarity_comparison <- function(lnr, new_lnr, deviations) {
 #' comparison, where a lower value indicates a better solution
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_train_errors}{\code{IAI.get_train_errors}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_train_errors}{\code{IAI.get_train_errors}}
 #'
 #' @param similarity The similarity comparison
 #'
@@ -1123,7 +1146,7 @@ get_train_errors <- function(similarity) {
 
 #' Construct a \href{https://ggplot2.tidyverse.org/reference/ggplot.html}{\code{ggplot2::ggplot}} object plotting the results of the similarity comparison
 #'
-#' @param x The similarity comparison to plot
+#' @param object The similarity comparison to plot
 #' @param ... Additional arguments (unused)
 #'
 #' @examples \dontrun{ggplot2::autoplot(similarity)}
@@ -1134,16 +1157,16 @@ get_train_errors <- function(similarity) {
 #' @importFrom ggplot2 autoplot
 #' @importFrom rlang .data
 #' @export
-autoplot.similarity_comparison <- function(x, ...) {
+autoplot.similarity_comparison <- function(object, ...) {
   requires_iai_version("2.2.0", "ggplot2::autoplot.similarity_comparison")
 
   plot_data <- data.frame(
-      deviations = x$deviations,
-      train_errors = get_train_errors(x),
+      deviations = object$deviations,
+      train_errors = get_train_errors(object),
       type = "All trees"
   )
 
-  plot_data$type[x$best_tree_index] <- "Selected tree"
+  plot_data$type[object$best_tree_index] <- "Selected tree"
 
   ggplot2::ggplot(plot_data, ggplot2::aes(x = .data$deviations,
                                           y = .data$train_errors,
@@ -1151,7 +1174,7 @@ autoplot.similarity_comparison <- function(x, ...) {
 
     ggplot2::geom_point() +
     # Redraw selected tree last so it shows up on top
-    ggplot2::geom_point(data = plot_data[x$best_tree_index, ]) +
+    ggplot2::geom_point(data = plot_data[object$best_tree_index, ]) +
     ggplot2::labs(x = "Deviation from original tree (lower is better)",
                   y = "Training objective value (lower is better)")
 }
@@ -1181,11 +1204,11 @@ plot.similarity_comparison <- function(x, ...) {
 #' Conduct a stability analysis of the trees in a tree learner
 #'
 #' Refer to the
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/stability/#Tree-Stability-1}{documentation on tree stability}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/stability/#Tree-Stability-1}{documentation on tree stability}
 #' for more information.
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.StabilityAnalysis}{\code{IAI.StabilityAnalysis}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.StabilityAnalysis}{\code{IAI.StabilityAnalysis}}
 #'
 #' @param lnr The original learner
 #' @param ... Additional arguments (refer to Julia documentation)
@@ -1206,7 +1229,7 @@ stability_analysis <- function(lnr, ...) {
 #' along with their variable importance scores for each feature
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_stability_results}{\code{IAI.get_stability_results}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_stability_results}{\code{IAI.get_stability_results}}
 #'
 #' @param stability The stability analysis to query
 #'
@@ -1226,7 +1249,7 @@ get_stability_results <- function(stability) {
 #' clustering of a given number of trees
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_cluster_assignments}{\code{IAI.get_cluster_assignments}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_cluster_assignments}{\code{IAI.get_cluster_assignments}}
 #'
 #' @param stability The stability analysis to query
 #' @param num_trees The number of trees to include in the clustering
@@ -1248,7 +1271,7 @@ get_cluster_assignments <- function(stability, num_trees) {
 #' given number of trees
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_cluster_details}{\code{IAI.get_cluster_details}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_cluster_details}{\code{IAI.get_cluster_details}}
 #'
 #' @param stability The stability analysis to query
 #' @param num_trees The number of trees to include in the clustering
@@ -1269,7 +1292,7 @@ get_cluster_details <- function(stability, num_trees) {
 #' the clustering of a given number of trees
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v3.1.0/IAITrees/reference/#IAI.get_cluster_distances}{\code{IAI.get_cluster_distances}}
+#' \href{https://docs.interpretable.ai/v3.1.1/IAITrees/reference/#IAI.get_cluster_distances}{\code{IAI.get_cluster_distances}}
 #'
 #' @param stability The stability analysis to query
 #' @param num_trees The number of trees to include in the clustering
@@ -1288,7 +1311,7 @@ get_cluster_distances <- function(stability, num_trees) {
 
 #' Construct a \href{https://ggplot2.tidyverse.org/reference/ggplot.html}{\code{ggplot2::ggplot}} object plotting the results of the stability analysis
 #'
-#' @param x The stability analysis to plot
+#' @param object The stability analysis to plot
 #' @param ... Additional arguments (unused)
 #'
 #' @examples \dontrun{ggplot2::autoplot(stability)}
@@ -1299,14 +1322,14 @@ get_cluster_distances <- function(stability, num_trees) {
 #' @importFrom ggplot2 autoplot
 #' @importFrom rlang .data
 #' @export
-autoplot.stability_analysis <- function(x, ...) {
+autoplot.stability_analysis <- function(object, ...) {
   requires_iai_version("2.2.0", "ggplot2::autoplot.stability_analysis")
 
   plot_data <- data.frame(
-      x = seq_along(x$train_errors),
-      train_errors = x$train_errors,
-      n_clusts = sapply(x$cluster_centers, ncol),
-      cluster_r2 = x$cluster_r2
+      x = seq_along(object$train_errors),
+      train_errors = object$train_errors,
+      n_clusts = sapply(object$cluster_centers, ncol),
+      cluster_r2 = object$cluster_r2
   )
 
   plot1 <- ggplot2::ggplot(plot_data,
